@@ -37,7 +37,7 @@
 #include "tools/kpTool.h"
 #include "views/manager/kpViewManager.h"
 
-#include <qrect.h>
+#include <QRect>
 
 
 struct kpToolFlowCommandPrivate
@@ -103,15 +103,14 @@ void kpToolFlowCommand::updateBoundingRect (const QPoint &point)
 void kpToolFlowCommand::updateBoundingRect (const QRect &rect)
 {
 #if DEBUG_KP_TOOL_FLOW_COMMAND & 0
-    kDebug () << "kpToolFlowCommand::updateBoundingRect()  existing="
+    qCDebug(kpLogCommands) << "kpToolFlowCommand::updateBoundingRect()  existing="
                << d->boundingRect
                << " plus="
-               << rect
-               << endl;
+               << rect;
 #endif
     d->boundingRect = d->boundingRect.united (rect);
 #if DEBUG_KP_TOOL_FLOW_COMMAND & 0
-    kDebug () << "\tresult=" << d->boundingRect;
+    qCDebug(kpLogCommands) << "\tresult=" << d->boundingRect;
 #endif
 }
 
